==> apache-doris-2.1.0-src.tar.gz: apache-doris-2.1.0-src/fe/fe-core/src/main/java/org/apache/doris/mtmv/MTMVJobInfo.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.doris.mtmv;

import org.apache.doris.common.Config;
import org.apache.doris.job.extensions.mtmv.MTMVTask;

import com.google.gson.annotations.SerializedName;

import java.util.concurrent.ConcurrentLinkedQueue;

/**
 * MTMVJobInfo
 */
public class MTMVJobInfo {
    @SerializedName("jobName")
    private String jobName;
    @SerializedName("ht")
    private ConcurrentLinkedQueue<MTMVTask> historyTasks;

    public MTMVJobInfo(String jobName) {
        this.jobName = jobName;
        historyTasks = new ConcurrentLinkedQueue<>();
    }

    public String getJobName() {
        return jobName;
    }

    public void addHistoryTask(MTMVTask task) {
        if (Config.max_persistence_task_count < 1) {
            return;
        }
        historyTasks.add(task);
        if (historyTasks.size() > Config.max_persistence_task_count) {
            historyTasks.poll();
        }
    }

    public ConcurrentLinkedQueue<MTMVTask> getHistoryTasks() {
        return historyTasks;
    }

    @Override
    public String toString() {
        return "MTMVJobInfo{"
                + "jobName='" + jobName + '\''
                + ", historyTasks=" + historyTasks
                + '}';
    }
}

==> apache-doris-2.1.8-rc01-src.tar.gz: apache-doris-2.1.8-rc01-src/fe/fe-core/src/main/java/org/apache/doris/mtmv/MTMVJobInfo.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.doris.mtmv;

import org.apache.doris.common.Config;
import org.apache.doris.job.extensions.mtmv.MTMVTask;

import com.google.gson.annotations.SerializedName;

import java.util.concurrent.ConcurrentLinkedQueue;

/**
 * MTMVJobInfo
 */
public class MTMVJobInfo {
    @SerializedName("jobName")
    private String jobName;
    @SerializedName("ht")
    private ConcurrentLinkedQueue<MTMVTask> historyTasks;

    public MTMVJobInfo(String jobName) {
        this.jobName = jobName;
        historyTasks = new ConcurrentLinkedQueue<>();
    }

    public String getJobName() {
        return jobName;
    }

    public void addHistoryTask(MTMVTask task) {
        if (Config.max_persistence_task_count < 1) {
            return;
        }
        historyTasks.add(task);
        if (historyTasks.size() > Config.max_persistence_task_count) {
            historyTasks.poll();
        }
    }

    public ConcurrentLinkedQueue<MTMVTask> getHistoryTasks() {
        return historyTasks;
    }

    // toString() is not easy to find where to call the method
    public String toInfoString() {
        return "MTMVJobInfo{"
                + "jobName='" + jobName + '\''
                + ", historyTasks=" + historyTasks
                + '}';
    }
}
